pro sxt_ssn2secondary, sssfiles, outsize=outsize, outres=outres, $
   outdir=outdir, prefix=prefix, yyyy=yyyy, ss=ss
;+
;   Name: sxt_ssn2fits
;
;   Purpose: convert ssc or sss files -> "Standard" FITs 
;            for export and -> YPOP/WWW movie maker
;
;   Input Parameters:
;      ssnfiles - file list to process
;  
;   Keyword Parameters:
;      outsize - size of output (for embedding, default = 576x576)
;      outres  - default = 1 (half res = ~2.54"/pix) 
;      outdir  - where to stick files
;
;   Side Effects:
;      data is registered to sun center - fits file written
;
;-
rd_roadmap,sssfiles,rmap
nim=n_elements(rmap)

time_root=time2file(rmap(0),delim='_') + '_to_' + time2file(last_nelem(rmap))
dir_root=time2file(rmap(0),/date_only)

if not keyword_set(movie_dir) then $
    movie_dir=(concat_dir(concat_dir('$path_http','last_sxt'),dir_root))(0)

index=concat_dir(movie_dir,'index.html')

if not file_exist(movie_dir) then begin 
   box_message,'Creating subdirectory: ' + movie_dir
   spawn,['mkdir','-p',movie_dir],/noshell
endif

if not keyword_set(outres)  then outres=1
if not keyword_set(outsize) then outsize=[576,576]
if not keyword_set(prefix) then $
     pref='sss_'+strtrim(gt_filtb(rmap,/string),2) + '_'   +      $
                   strtrim(gt_shape_cmd(rmap,/x,/string),2) + '_' + $
                   strtrim(outsize(0),2) + '_' else pref=replicate(prefix,nim)

if not keyword_set(outdir) then outdir=movie_dir

case 1 of 
    keyword_set(yyyy): $
        odir=concat_dir(outdir,strmid(time2file(rmap),0,4))
    else: odir=replicate(outdir,nim)
endcase

if not keyword_set(ss) then ss=lindgen(nim)

sxt_prep, sssfiles, ss, outindex, outdata, $
      /reg, suncoord=[0,0], /sfd_cor, /roll, outres=outres, outsize=outsize

outindex=struct2ssw(outindex)                     ; rationalize 'index'

;  --- add tags/history/comments here? ----
for i=0,nim-1 do $
mwritefits, outindex(i), outdata(*,*,i), outdir=odir(i),prefix=pref(i) ;index,data->fits

if max(outdata) gt 256 then sdata=safe_log10(outindex,outdata,/byte) else $
   sdata=temporary(outdata)

; ------- generate corresponding GOES movie
event_movie, outindex, gmovie,/goes, /zbuff, $
        outsize=[outsize(0),180] 
gmovie=[[sdata],[gmovie]]

; --------- make thumbnail table movie -------------
image2movie, sdata, ut_times=outindex, /inctimes, /still, html=stillhtml, $
        table=3, /reverse, thumbsize=128, movie_dir=movie_dir

; ----- make JS/MPEG/Gif-animate sequence -----------
special_movie, outindex, gmovie, thumbsize=128, movie_dir=movie_dir,$
        table=3, /reverse, /no_htmldoc, /inctime, html=moviehtml

; ------------- generate html index ----------------
html_doc, index,  /header
file_append,index,'<h3> ' + anytim(rmap(0),/ecs) + ' -TO- ' +$
                            anytim(last_nelem(rmap),/ecs) + '</h3>

file_append, index, moviehtml
file_append, index, stillhtml
file_append, index, ['<p>',$
   '<b> FITS files <SHIFT>/Left Click to copy to local machine</b><p>']

ffiles=file_list(movie_dir,'*.fits')
break_file,ffiles,ll,pp,ff,ee,vv
ftext=ff+'.fits ' + get_info(rmap,/non)
file_append,index,str_replace(str2html(ff+'.gif', $
                     link_text=link_text),'.gif','.fits')
html_doc,index,/trailer
; --------------------------------------------------------

return
end
